@@ -1,5 +1,5 @@
-require 'spreadsheet/format'
-require 'spreadsheet/encodings'
+require "spreadsheet/format"
+require "spreadsheet/encodings"
 
 module Spreadsheet
   ##
@@ -14,17 +14,18 @@ module Spreadsheet
     include Spreadsheet::Encodings
     attr_reader :io, :worksheets, :formats, :fonts, :palette
     attr_accessor :active_worksheet, :encoding, :default_format, :version
-    def initialize io = nil, opts={:default_format => Format.new}
+    def initialize io = nil, opts = {default_format: Format.new}
       @worksheets = []
       @io = io
       @fonts = []
       @palette = {}
       @formats = []
       @formats_set = {}
-      if @default_format = opts[:default_format]
+      if (@default_format = opts[:default_format])
         add_format @default_format
       end
     end
+
     ##
     # Add a Font to the Workbook. Used by the parser. You should not need to
     # use this Method.
@@ -32,6 +33,7 @@ module Spreadsheet
       @fonts.push(font).uniq! if font
       font
     end
+
     ##
     # Add a Format to the Workbook. If you use Row#set_format, you should not
     # need to use this Method.
@@ -42,6 +44,7 @@ module Spreadsheet
       end
       format
     end
+
     ##
     # Add a Worksheet to the Workbook.
     def add_worksheet worksheet
@@ -49,18 +52,21 @@ module Spreadsheet
       @worksheets.push worksheet
       worksheet
     end
+
     ##
     # Delete a Worksheet from Workbook by it's index
     def delete_worksheet worksheet_index
       @worksheets.delete_at worksheet_index
     end
+
     ##
     # Change the RGB components of the elements in the colour palette.
     def set_custom_color idx, red, green, blue
-      raise 'Invalid format' if [red, green, blue].find { |c| ! (0..255).include?(c) }
+      raise "Invalid format" if [red, green, blue].find { |c| !(0..255).cover?(c) }
 
       @palette[idx] = [red, green, blue]
     end
+
     ##
     # Create a new Worksheet in this Workbook.
     # Used without options this creates a Worksheet with the name 'WorksheetN'
@@ -69,20 +75,23 @@ module Spreadsheet
     # Use the option <em>:name => 'My pretty Name'</em> to override this
     # behavior.
     def create_worksheet opts = {}
-      opts[:name] ||= client("Worksheet#{@worksheets.size.next}", 'UTF-8')
+      opts[:name] ||= client("Worksheet#{@worksheets.size.next}", "UTF-8")
       add_worksheet Worksheet.new(opts)
     end
+
     ##
     # Returns the count of total worksheets present.
     # Takes no arguments. Just returns the length of @worksheets array.
     def sheet_count
       @worksheets.length
     end
+
     ##
     # The Font at _idx_
     def font idx
       @fonts[idx]
     end
+
     ##
     # The Format at _idx_, or - if _idx_ is a String -
     # the Format with name == _idx_
@@ -91,23 +100,26 @@ module Spreadsheet
       when Integer
         @formats[idx] || @default_format || Format.new
       when String
-        @formats.find do |fmt| fmt.name == idx end
+        @formats.find { |fmt| fmt.name == idx }
       end
     end
+
     def inspect
       variables = (instance_variables - uninspect_variables).collect do |name|
         "%s=%s" % [name, instance_variable_get(name)]
-      end.join(' ')
+      end.join(" ")
       uninspect = uninspect_variables.collect do |name|
         var = instance_variable_get name
         "%s=%s[%i]" % [name, var.class, var.size]
-      end.join(' ')
+      end.join(" ")
       sprintf "#<%s:0x%014x %s %s>", self.class, object_id,
-                                     variables, uninspect
+        variables, uninspect
     end
+
     def uninspect_variables # :nodoc:
-      %w{@formats @fonts @worksheets}
+      %w[@formats @fonts @worksheets]
     end
+
     ##
     # The Worksheet at _idx_, or - if _idx_ is a String -
     # the Worksheet with name == _idx_
@@ -116,9 +128,10 @@ module Spreadsheet
       when Integer
         @worksheets[idx]
       when String
-        @worksheets.find do |sheet| sheet.name == idx end
+        @worksheets.find { |sheet| sheet.name == idx }
       end
     end
+
     ##
     # Write this Workbook to a File, IO Stream or Writer Object. The latter will
     # make more sense once there are more than just an Excel-Writer available.
@@ -129,10 +142,11 @@ module Spreadsheet
         writer(io_path_or_writer).write(self)
       end
     end
+
     ##
     # Returns a new instance of the default Writer class for this Workbook (can
     # only be an Excel::Writer::Workbook at this time)
-    def writer io_or_path, type=Excel, version=self.version
+    def writer io_or_path, type = Excel, version = self.version
       if type == Excel
         Excel::Writer::Workbook.new io_or_path
       else
