@@ -1,9 +1,9 @@
 #!/usr/bin/env ruby
 # Excel::TestReader -- Spreadsheet -- 22.01.2013
 
-$: << File.expand_path('../../../lib', File.dirname(__FILE__))
+$: << File.expand_path("../../../lib", File.dirname(__FILE__))
 
-require 'test/unit'
+require "test/unit"
 
 module Spreadsheet
   module Excel
@@ -18,8 +18,8 @@ module Spreadsheet
 
       def test_not_empty_file_error_on_setup
         reader = Spreadsheet::Excel::Reader.new
-        data = File.expand_path File.join('test', 'data')
-        path = File.join data, 'test_empty.xls'
+        data = File.expand_path File.join("test", "data")
+        path = File.join data, "test_empty.xls"
         not_empty_io = File.open(path, "rb")
         assert_nothing_thrown do
           reader.setup not_empty_io
@@ -27,11 +27,11 @@ module Spreadsheet
       end
 
       def test_not_frozen_stream_error_on_setup
-        return if Gem::Version.new(RUBY_VERSION) < Gem::Version.new('2.3.0')
+        return if Gem::Version.new(RUBY_VERSION) < Gem::Version.new("2.3.0")
 
         reader = Spreadsheet::Excel::Reader.new
-        data = File.expand_path File.join('test', 'data')
-        path = File.join data, 'test_empty.xls'
+        data = File.expand_path File.join("test", "data")
+        path = File.join data, "test_empty.xls"
         content_string = File.read path
         frozen_io = StringIO.new(content_string.freeze)
         assert_nothing_thrown do
@@ -40,4 +40,4 @@ module Spreadsheet
       end
     end
   end
-end
\ No newline at end of file
+end
